@@ -1,7 +1,4 @@
 import logging
-from functools import wraps
-from socket import gaierror
-from time import sleep
 from typing import Union, Optional, Dict
 
 import pandas as pd
@@ -13,44 +10,20 @@ from bs4 import BeautifulSoup
 from entsoe.exceptions import InvalidPSRTypeError, InvalidBusinessParameterError
 from .exceptions import NoMatchingDataError, PaginationError
 from .mappings import Area, NEIGHBOURS, lookup_area
-from .misc import year_blocks, day_blocks
 from .parsers import parse_prices, parse_loads, parse_generation, \
     parse_installed_capacity_per_plant, parse_crossborder_flows, \
     parse_unavailabilities, parse_contracted_reserve, parse_imbalance_prices_zip, \
     parse_netpositions, parse_procured_balancing_capacity
+from .decorators import retry, paginated, year_limited, day_limited
 
 __title__ = "entsoe-py"
-__version__ = "0.4"
+__version__ = "0.4.1"
 __author__ = "EnergieID.be"
 __license__ = "MIT"
 
 URL = 'https://transparency.entsoe.eu/api'
 
 
-def retry(func):
-    """Catches connection errors, waits and retries"""
-
-    @wraps(func)
-    def retry_wrapper(*args, **kwargs):
-        self = args[0]
-        error = None
-        for _ in range(self.retry_count):
-            try:
-                result = func(*args, **kwargs)
-            except (requests.ConnectionError, gaierror) as e:
-                error = e
-                print("Connection Error, retrying in {} seconds".format(
-                    self.retry_delay))
-                sleep(self.retry_delay)
-                continue
-            else:
-                return result
-        else:
-            raise error
-
-    return retry_wrapper
-
-
 class EntsoeRawClient:
     # noinspection LongLine
     """
@@ -928,79 +901,6 @@ class EntsoeRawClient:
             country_code=country_code, start=start, end=end,
             doctype="A80", docstatus='A13')
         return content
-    
-
-
-def paginated(func):
-    """Catches a PaginationError, splits the requested period in two and tries
-    again. Finally it concatenates the results"""
-
-    @wraps(func)
-    def pagination_wrapper(*args, start, end, **kwargs):
-        try:
-            df = func(*args, start=start, end=end, **kwargs)
-        except PaginationError:
-            pivot = start + (end - start) / 2
-            df1 = pagination_wrapper(*args, start=start, end=pivot, **kwargs)
-            df2 = pagination_wrapper(*args, start=pivot, end=end, **kwargs)
-            df = pd.concat([df1, df2])
-        return df
-
-    return pagination_wrapper
-
-
-def year_limited(func):
-    """Deals with calls where you cannot query more than a year, by splitting
-    the call up in blocks per year"""
-
-    @wraps(func)
-    def year_wrapper(*args, start, end, **kwargs):
-        blocks = year_blocks(start, end)
-        frames = []
-        for _start, _end in blocks:
-            try:
-                frame = func(*args, start=_start, end=_end, **kwargs)
-            except NoMatchingDataError:
-                logging.debug(f"NoMatchingDataError: between {_start} and {_end}")
-                frame = None
-            frames.append(frame)
-
-        if sum([f is None for f in frames]) == len(frames):
-            # All the data returned are void
-            raise NoMatchingDataError
-
-        df = pd.concat(frames, sort=True)
-        df = df.loc[~df.index.duplicated(keep='first')]
-        return df
-
-    return year_wrapper
-
-
-def day_limited(func):
-    """Deals with calls where you cannot query more than a year, by splitting
-    the call up in blocks per year"""
-
-    @wraps(func)
-    def day_wrapper(*args, start, end, **kwargs):
-        blocks = day_blocks(start, end)
-        frames = []
-        for _start, _end in blocks:
-            try:
-                frame = func(*args, start=_start, end=_end, **kwargs)
-            except NoMatchingDataError:
-                print(f"NoMatchingDataError: between {_start} and {_end}")
-                frame = None
-            frames.append(frame)
-
-        if sum([f is None for f in frames]) == len(frames):
-            # All the data returned are void
-            raise NoMatchingDataError
-
-        df = pd.concat(frames)
-        return df
-
-    return day_wrapper
-
 
 class EntsoePandasClient(EntsoeRawClient):
     @year_limited
@@ -1051,7 +951,7 @@ class EntsoePandasClient(EntsoeRawClient):
 
     @year_limited
     def query_load(self, country_code: Union[Area, str], start: pd.Timestamp,
-                   end: pd.Timestamp) -> pd.Series:
+                   end: pd.Timestamp) -> pd.DataFrame:
         """
         Parameters
         ----------
@@ -1066,7 +966,7 @@ class EntsoePandasClient(EntsoeRawClient):
         area = lookup_area(country_code)
         text = super(EntsoePandasClient, self).query_load(
             country_code=area, start=start, end=end)
-        series = parse_loads(text)
+        series = parse_loads(text, process_type='A16')
         series = series.tz_convert(area.tz)
         series = series.truncate(before=start, after=end)
         return series
@@ -1096,6 +996,27 @@ class EntsoePandasClient(EntsoeRawClient):
         df = df.truncate(before=start, after=end)
         return df
 
+    def query_load_and_forecast(
+            self, country_code: Union[Area, str], start: pd.Timestamp,
+            end: pd.Timestamp) -> pd.DataFrame:
+        """
+        utility function to combina query realised load and forecasted day ahead load.
+        this mimics the html view on the page Total Load - Day Ahead / Actual
+
+        Parameters
+        ----------
+        country_code : Area|str
+        start : pd.Timestamp
+        end : pd.Timestamp
+
+        Returns
+        -------
+        pd.DataFrame
+        """
+        df_load_forecast_da = self.query_load_forecast(country_code, start=start, end=end)
+        df_load = self.query_load(country_code, start=start, end=end)
+        return df_load_forecast_da.join(df_load, sort=True, how='inner')
+
 
     @year_limited
     def query_generation_forecast(
